You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2020/09/27 15:54:02 UTC

[commons-io] branch master updated: Revert "Use stock JRE null checking Objects.requireNonNull()."

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-io.git


The following commit(s) were added to refs/heads/master by this push:
     new cb55c57  Revert "Use stock JRE null checking Objects.requireNonNull()."
cb55c57 is described below

commit cb55c57c1b28530558f18f2478ec0d0cc97920c2
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Sun Sep 27 11:53:47 2020 -0400

    Revert "Use stock JRE null checking Objects.requireNonNull()."
    
    This reverts commit d0cd953c69a39bc2605ac08dbce8b39e084f4ef0.
---
 src/main/java/org/apache/commons/io/filefilter/NotFileFilter.java | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/src/main/java/org/apache/commons/io/filefilter/NotFileFilter.java b/src/main/java/org/apache/commons/io/filefilter/NotFileFilter.java
index ea7b8c7..3a76d2e 100644
--- a/src/main/java/org/apache/commons/io/filefilter/NotFileFilter.java
+++ b/src/main/java/org/apache/commons/io/filefilter/NotFileFilter.java
@@ -18,7 +18,6 @@ package org.apache.commons.io.filefilter;
 
 import java.io.File;
 import java.io.Serializable;
-import java.util.Objects;
 
 /**
  * This filter produces a logical NOT of the filters specified.
@@ -37,10 +36,13 @@ public class NotFileFilter extends AbstractFileFilter implements Serializable {
      * Constructs a new file filter that NOTs the result of another filter.
      *
      * @param filter the filter, must not be null
      * @throws NullPointerException if the filter is null
      */
     public NotFileFilter(final IOFileFilter filter) {
-        this.filter = Objects.requireNonNull(filter, "filter");
+        if (filter == null) {
+            throw new IllegalArgumentException("The filter must not be null");
+        }
+        this.filter = filter;
     }
 
     /**
@@ -37,10 +36,13 @@ public class NotFileFilter extends AbstractFileFilter implements Serializable {
      *
      * @param filter the filter, must not be null
-     * @throws NullPointerException if the filter is null
+     * @throws IllegalArgumentException if the filter is null
      */
     public NotFileFilter(final IOFileFilter filter) {